@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: (GPL-2.0 OR BSD-2-Clause)
 
-ALL_TESTS="test_link_so test_link_a test_old_dispatcher test_xdp_frags test_xsk_prog_refcnt_bpffs test_xsk_prog_refcnt_legacy test_xsk_non_privileged test_link_detach test_xsk_umem_flags"
+ALL_TESTS="test_link_so test_link_a test_old_dispatcher test_xdp_devbound test_xdp_frags test_xsk_prog_refcnt_bpffs test_xsk_prog_refcnt_legacy test_xsk_non_privileged test_link_detach test_xsk_umem_flags"
 
 TESTS_DIR=$(dirname "${BASH_SOURCE[0]}")
 
@@ -94,6 +94,18 @@ test_xdp_frags()
         ip link delete xdp_veth_small0
 }
 
+test_xdp_devbound()
+{
+	check_mount_bpffs || return 1
+	skip_if_missing_libxdp_compat
+
+	ip link add xdp_veth0 type veth peer name xdp_veth1
+	ip link add xdp_veth2 type veth peer name xdp_veth3
+	check_run $TESTS_DIR/test_xdp_devbound xdp_veth1 xdp_veth3 2>&1
+	ip link delete xdp_veth0
+	ip link delete xdp_veth2
+}
+
 test_old_dispatcher()
 {
         check_mount_bpffs || return 1
