@@ -68,7 +68,7 @@
 #define SO_BUSY_POLL_BUDGET     70
 #endif
 
-#define NUM_FRAMES (4 * 1024)
+#define NUM_FRAMES (4 * 1024UL)
 #define IS_EOP_DESC(options) (!((options) & XDP_PKT_CONTD))
 
 #define DEBUG_HEXDUMP 0
@@ -166,8 +166,13 @@ struct xsk_socket_info {
 static unsigned long get_nsecs(clockid_t clock)
 {
 	struct timespec ts;
+	int res;
 
-	clock_gettime(clock, &ts);
+	res = clock_gettime(clock, &ts);
+	if (res < 0) {
+		pr_warn("Error with gettimeofday! (%i)\n", res);
+		return UINT64_MAX;
+	}
 	return ts.tv_sec * 1000000000UL + ts.tv_nsec;
 }
 
@@ -303,26 +308,26 @@ static int get_irqs(const struct xsk_ctx *ctx)
 static void dump_driver_stats(struct xsk_ctx *ctx, long dt)
 {
 #define PPS(_now, _prev) ((_now - _prev) * 1000000000. / dt)
-	unsigned int i;
+	char *fmt = " %-18s %'14.0f intrs/s\n";
+	unsigned int i = 0;
+	double intrs_ps;
+	int n_ints;
 
-	for (i = 0; i < ctx->num_socks && ctx->xsks[i]; i++) {
-		char *fmt = " %-18s %'14.0f intrs/s\n";
-		double intrs_ps;
-		int n_ints = get_irqs(ctx);
+	if (i >= ctx->num_socks || !ctx->xsks[i])
+		return;
 
-		if (n_ints < 0) {
-			printf("error getting intr info for intr %i\n", ctx->irq_no);
-			return;
-		}
-		ctx->xsks[i]->drv_stats.intrs = n_ints - ctx->irqs_at_init;
-
-		intrs_ps = PPS(ctx->xsks[i]->drv_stats.intrs, ctx->xsks[i]->drv_stats.prev_intrs);
-
-		printf(fmt, "IRQs", intrs_ps);
-
-		ctx->xsks[i]->drv_stats.prev_intrs = ctx->xsks[i]->drv_stats.intrs;
-		break;
+	n_ints = get_irqs(ctx);
+	if (n_ints < 0) {
+		printf("error getting intr info for intr %i\n", ctx->irq_no);
+		return;
 	}
+	ctx->xsks[i]->drv_stats.intrs = n_ints - ctx->irqs_at_init;
+
+	intrs_ps = PPS(ctx->xsks[i]->drv_stats.intrs, ctx->xsks[i]->drv_stats.prev_intrs);
+
+	printf(fmt, "IRQs", intrs_ps);
+
+	ctx->xsks[i]->drv_stats.prev_intrs = ctx->xsks[i]->drv_stats.intrs;
 #undef PPS
 }
 
@@ -832,7 +837,7 @@ __wsum csum_tcpudp_nofold(__be32 saddr, __be32 daddr,
 #ifdef __BIG_ENDIAN__
 	s += proto + len;
 #else
-	s += (proto + len) << 8;
+	s += ((unsigned long long)proto + len) << 8;
 #endif
 	return (__wsum)from64to32(s);
 }
@@ -966,7 +971,7 @@ static void gen_eth_frames(struct xsk_ctx *ctx, struct xsk_umem_info *umem, __u3
 	unsigned int i;
 
 	for (i = 0; i < NUM_FRAMES; i++) {
-		__u64 addr = i * frame_size;
+		__u64 addr = (__u64)i * frame_size;
 
 		if (!len) {
 			len = PKT_SIZE(&ctx->opt);
@@ -1031,8 +1036,8 @@ static int xsk_populate_fill_ring(struct xsk_umem_info *umem, __u32 frame_size)
 		return -ret;
 
 	for (i = 0; i < XSK_RING_PROD__DEFAULT_NUM_DESCS * 2; i++)
-		*xsk_ring_prod__fill_addr(&umem->fq, idx++) =
-			i * frame_size;
+		*xsk_ring_prod__fill_addr(&umem->fq, idx++) = (__u64)i * frame_size;
+
 	xsk_ring_prod__submit(&umem->fq, XSK_RING_PROD__DEFAULT_NUM_DESCS * 2);
 
 	return 0;
@@ -1144,8 +1149,9 @@ static inline int complete_tx_l2fwd(struct xsk_socket_info *xsk,
 				return ret;
 			if (busy_poll || xsk_ring_prod__needs_wakeup(&umem->fq)) {
 				xsk->app_stats.fill_fail_polls++;
-				recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0, MSG_DONTWAIT, NULL,
-					 NULL);
+				if (recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0,
+					     MSG_DONTWAIT, NULL, NULL) < 0)
+					return -errno;
 			}
 			ret = xsk_ring_prod__reserve(&umem->fq, rcvd, &idx_fq);
 		}
@@ -1192,7 +1198,9 @@ static int rx_drop(struct xsk_socket_info *xsk, __u32 batch_size, bool busy_poll
 	if (!rcvd) {
 		if (busy_poll || xsk_ring_prod__needs_wakeup(&xsk->umem->fq)) {
 			xsk->app_stats.rx_empty_polls++;
-			recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0, MSG_DONTWAIT, NULL, NULL);
+			if (recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0,
+				     MSG_DONTWAIT, NULL, NULL) < 0)
+				return -errno;
 		}
 		return 0;
 	}
@@ -1203,7 +1211,9 @@ static int rx_drop(struct xsk_socket_info *xsk, __u32 batch_size, bool busy_poll
 			return ret;
 		if (busy_poll || xsk_ring_prod__needs_wakeup(&xsk->umem->fq)) {
 			xsk->app_stats.fill_fail_polls++;
-			recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0, MSG_DONTWAIT, NULL, NULL);
+			if (recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0,
+				     MSG_DONTWAIT, NULL, NULL) < 0)
+				return -errno;
 		}
 		ret = xsk_ring_prod__reserve(&xsk->umem->fq, rcvd, &idx_fq);
 	}
@@ -1260,8 +1270,8 @@ static void *xsk_rx_drop_all(void *arg)
 static int tx_only(struct xsk_ctx *ctx, struct xsk_socket_info *xsk, __u32 *frame_nb,
 		   int batch_size, unsigned long tx_ns)
 {
-	__u32 idx, tv_sec, tv_usec;
 	int i;
+	__u32 idx, tv_sec = 0, tv_usec = 0;
 
 	while (xsk_ring_prod__reserve(&xsk->tx, batch_size, &idx) <
 	       (unsigned int)batch_size) {
@@ -1281,7 +1291,7 @@ static int tx_only(struct xsk_ctx *ctx, struct xsk_socket_info *xsk, __u32 *fram
 		do {
 			struct xdp_desc *tx_desc = xsk_ring_prod__tx_desc(&xsk->tx,
 									  idx + i);
-			tx_desc->addr = *frame_nb * ctx->opt.frame_size;
+			tx_desc->addr = (__u64)*frame_nb * ctx->opt.frame_size;
 			if (len > ctx->opt.frame_size) {
 				tx_desc->len = ctx->opt.frame_size;
 				tx_desc->options = XDP_PKT_CONTD;
@@ -1447,7 +1457,9 @@ static int l2fwd(struct xsk_ctx *ctx, struct xsk_socket_info *xsk)
 	if (!rcvd) {
 		if (ctx->opt.busy_poll || xsk_ring_prod__needs_wakeup(&xsk->umem->fq)) {
 			xsk->app_stats.rx_empty_polls++;
-			recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0, MSG_DONTWAIT, NULL, NULL);
+			if (recvfrom(xsk_socket__fd(xsk->xsk), NULL, 0,
+				     MSG_DONTWAIT, NULL, NULL) < 0)
+				return -errno;
 		}
 		return 0;
 	}
@@ -1884,7 +1896,7 @@ int xsk_validate_opts(const struct xsk_opts *opt)
 		return -EINVAL;
 	}
 	if (opt->timestamp && opt->tx_pkt_size < PKTGEN_SIZE_MIN(opt)) {
-		pr_warn("TX packet size %d less than minimum %lu bytes when timestamps are enabled\n",
+		pr_warn("TX packet size %d less than minimum %zu bytes when timestamps are enabled\n",
 			opt->tx_pkt_size, PKTGEN_SIZE_MIN(opt));
 		return -EINVAL;
 	}
